.. _credits:

********
Credits
********

* `os <https://docs.python.org/3/library/os.html>`_
* `shutil <https://docs.python.org/3/library/shutil.html>`_
* `re <https://docs.python.org/3/library/re.html>`_
* `time <https://docs.python.org/3/library/time.html>`_
* `hashlib <https://docs.python.org/3/library/hashlib.html>`_
* `subprocess <https://docs.python.org/3/library/subprocess.html>`_